@@ -323,21 +323,21 @@ const char *ScriptChecks::chkSlog(Line *line, ScriptImage *img)
 
 	if(member)
 	{
-                if(!stricmp(member, "debug"))
+                if(!stricmp(member, ".debug"))
                         member = NULL;
-                else if(!stricmp(member, "info"))
+                else if(!stricmp(member, ".info"))
                         member = NULL;
-                else if(!stricmp(member, "notice"))
+                else if(!stricmp(member, ".notice"))
                         member = NULL;
-                else if(!strnicmp(member, "warn", 4))
+                else if(!strnicmp(member, ".warn", 5))
                         member = NULL;
-                else if(!strnicmp(member, "err", 3))
+                else if(!strnicmp(member, ".err", 4))
                         member = NULL;
-                else if(!strnicmp(member, "crit", 4))
+                else if(!strnicmp(member, ".crit", 5))
                         member = NULL;
-                else if(!stricmp(member, "alert"))
+                else if(!stricmp(member, ".alert"))
 			member = NULL;
-                else if(!strnicmp(member, "emerg", 5))
+                else if(!strnicmp(member, ".emerg", 6))
                         member = NULL;
 	}
 
@@ -403,7 +403,7 @@ const char *ScriptChecks::chkExpr(Line *line, ScriptImage *img)
 {
         const char *cp = getMember(line);
 
-        if(cp && !isdigit(cp[1]))
+        if(cp && !isdigit(cp[0]))
 	{
                 cp = chkProperty(line, img);
 
@@ -411,7 +411,7 @@ const char *ScriptChecks::chkExpr(Line *line, ScriptImage *img)
 			return cp;
 	}
 
-	if(cp && atoi(++cp) > 6)
+	if(cp && atoi(cp) > 6)
 		return "numbers only valid to 6 decimal places";
 
 	if(hasKeywords(line))
@@ -435,7 +435,7 @@ const char *ScriptChecks::chkString(Line *line, ScriptImage *img)
 {
 	const char *cp = getMember(line);
 
-	if(cp && !isdigit(cp[1]))
+	if(cp && !isdigit(cp[0]))
 		return "member when used must be size";
 
 	if(!useKeywords(line, "=size"))
@@ -494,7 +494,7 @@ const char *ScriptChecks::chkVar(Line *line, ScriptImage *img)
 {
         const char *cp = getMember(line);
 
-        if(cp && !isdigit(cp[1]))
+        if(cp && !isdigit(cp[0]))
 	{
                 cp = chkProperty(line, img);
 		if(!cp)
@@ -514,10 +514,10 @@ const char *ScriptChecks::chkNumber(Line *line, ScriptImage *img)
 {
 	const char *cp = getMember(line);
 
-	if(cp && !isdigit(cp[1]))
+	if(cp && !isdigit(cp[0]))
 		return "member must be decimal place";
 
-	if(cp && atoi(++cp) > 6)
+	if(cp && atoi(cp) > 6)
 		return "numbers supported only to 6 decimal places";
 
 	if(!useKeywords(line, "=decimal"))
@@ -624,7 +624,7 @@ const char *ScriptChecks::chkFirstVar(Line *line, ScriptImage *img)
 const char *ScriptChecks::chkArray(Line *line, ScriptImage *img)
 {
 	const char *cp = getMember(line);
-	if(cp && !isdigit(*(++cp)))
+	if(cp && !isdigit(*cp))
 		return "invalid member used";
 
 	if(!useKeywords(line, "=count=size"))
@@ -641,7 +641,7 @@ const char *ScriptChecks::chkSet(Line *line, ScriptImage *img)
 {
 	const char *cp = getMember(line);
 
-	if(cp && !isdigit(*(++cp)))
+	if(cp && !isdigit(*cp))
 		cp = chkProperty(line, img);
 	else
 		cp = NULL;
@@ -730,7 +730,7 @@ const char *ScriptChecks::chkCounter(Line *line, ScriptImage *img)
 {
 	const char *cp = getMember(line);
 
-	if(cp && atoi(++cp) < 1)
+	if(cp && atoi(cp) < 1)
 		return "member must be initial value and greater than zero";
 
 	if(hasKeywords(line))
@@ -778,7 +778,7 @@ const char *ScriptChecks::chkProperty(Line *line, ScriptImage *img)
         if(!cp) 
                 return NULL;
 
-        prop = ScriptProperty::find(++cp);
+        prop = ScriptProperty::find(cp);
         if(!prop)
                 return "unknown script property referenced";
 
