@@ -771,7 +771,9 @@ compile:
 			scrStream->getline(buffer + offset, bufsize - 1 - offset);
 			if(scrStream->eof())
 			{
-				if(wrapper && !execflag)
+				if(keydata && !script->first)
+					goto keytoken;
+				else if(wrapper && !execflag)
 				{
 					wrapper = false;
 					execflag = true;
@@ -859,6 +861,7 @@ compile:
 				}
 			}
 
+keytoken:
 			if(keydata && !script->first)
 			{
 				command = "_keydata_";
