@@ -489,8 +489,9 @@ bool ScriptInterp::conditionalExpression(void)
 		case symCONST:
 		case symSEQUENCE:
 			return false;
+		default:
+			return true;
 		}
-		return true;
 	}
 
         if(!stricmp(op, "!modify") || !stricmp(op, "-const"))
@@ -505,8 +506,9 @@ bool ScriptInterp::conditionalExpression(void)
                 case symCONST:
                 case symSEQUENCE:
                         return true;
+		default:
+			return false;
                 }
-                return false;
         }  
 
         if(!stricmp(op, "-queue"))
@@ -520,8 +522,9 @@ bool ScriptInterp::conditionalExpression(void)
                 case symSTACK:
 		case symFIFO:
                         return true;
+		default:
+			return false;
                 }
-                return false;
         }
 
         if(!stricmp(op, "!queue"))
@@ -535,8 +538,9 @@ bool ScriptInterp::conditionalExpression(void)
                 case symFIFO:
 		case symSTACK:
                         return false;
+		default:
+			return true;
                 }
-                return true;
         }
 
 	if(!stricmp(op, "-array"))
@@ -549,8 +553,9 @@ bool ScriptInterp::conditionalExpression(void)
 		{
 		case symARRAY:
 			return true;
+		default:
+			return false;
 		}
-		return false;
 	}
 
         if(!stricmp(op, "!array"))  
@@ -563,8 +568,9 @@ bool ScriptInterp::conditionalExpression(void)
                 {
                 case symARRAY:
                         return false;
+		default:
+			return true;
                 }
-                return true;
         }   
    
 	if(!stricmp(op, "-defined"))
@@ -619,8 +625,9 @@ bool ScriptInterp::conditionalExpression(void)
 		case symNUMBER:
 			if(!sym->data[0])
 				return false;
+		default:
+			return true;
 		}
-		return true;
 	}
 
 	if(!stricmp(op, "!active"))
@@ -660,8 +667,9 @@ bool ScriptInterp::conditionalExpression(void)
 		case symNUMBER:
 			if(!sym->data[0])
 				return true;
+		default:
+			return false;
 		}
-		return false;
 	}
 
 
