@@ -199,8 +199,9 @@ bool Script::isFunction(Name *scr)
 	case scrFUNCTION:
 	case scrLOCAL:
 		return true;
+	default:
+		return false;
 	}
-	return false;
 }
 
 bool Script::isPrivate(Name *scr)
@@ -210,8 +211,9 @@ bool Script::isPrivate(Name *scr)
 	case scrLOCAL:
 	case scrPRIVATE:
 		return true;
+	default:
+		return false;
 	}
-	return false;
 }
 
 unsigned Script::getIndex(const char *id)
@@ -321,6 +323,7 @@ void Script::clear(Symbol *sym)
 		return;	
 	case symTIMER:
 		sym->data[0] = 0;
+	default:
 		return;				
 	}
 }
@@ -363,8 +366,9 @@ unsigned Script::storage(Symbol *sym)
 	case symINITIAL:
 	case symNORMAL:
 		return sym->size;		
+	default:
+		return 0;
 	}
-	return 0;
 }
 
 const char *Script::extract(Symbol *sym)
@@ -479,7 +483,6 @@ bool Script::commit(Symbol *sym, const char *value)
 	Array *a;
 	long val;
 	unsigned short pos, npos, len;
-	unsigned offset = 0;
 	int dec = 0;
 	char *dp;
 	const char *sp;
